@@ -21,7 +21,7 @@
  */
 
 #include <arglex.h>
-#include <error_intl.h>
+#include <help.h>
 #include <verbose.h>
 
 
@@ -33,17 +33,7 @@ verbose_set()
 {
 	if (flag)
 	{
-		sub_context_ty	*scp;
-
-		scp = sub_context_new();
-		sub_var_set
-		(
-			scp,
-			"Name",
-			"%s",
-			arglex_token_name(arglex_token_verbose)
-		);
-		fatal_intl(scp, i18n("duplicate \"$name\" option"));
+		arg_duplicate(arglex_token_verbose, 0);
 		/* NOTREACHED */
 	}
 	flag = 1;
