@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997, 1998, 1999 Peter Miller;
+ *	Copyright (C) 1997, 1998, 1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -49,6 +49,8 @@ enum flag_value_ty
 	RF_IMPLICIT_ALLOWED_OFF,
 	RF_INCLUDE_COOKED_WARNING,
 	RF_INCLUDE_COOKED_WARNING_OFF,
+	RF_INGREDIENTS_FINGERPRINT,
+	RF_INGREDIENTS_FINGERPRINT_OFF,
 	RF_METER,
 	RF_METER_OFF,
 	RF_MKDIR,
