@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997, 1998, 1999, 2001 Peter Miller;
+ *	Copyright (C) 1997-1999, 2001, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -1146,7 +1146,7 @@ graph_build_file(gp, target, preference, result, implicit_allowed)
 	graph_file_list_nrc_ty common_ingredients_gfl;
 
 	trace(("graph_build_file(gp = %8.8lX, target = %08lX, preference = %d, \
-result = %8.8lX, imp=%d)\n{\n"/*}*/,
+result = %8.8lX, imp=%d)\n{\n",
 		(long)gp, (long)target, (int)preference, (long)result,
 		implicit_allowed));
 	result->status = graph_build_status_error;
@@ -1161,7 +1161,7 @@ result = %8.8lX, imp=%d)\n{\n"/*}*/,
 	 * remove "./" for the start of file names,
 	 * so that more recipes apply
 	 */
-	strip_dot(&target);
+	target = strip_dot(target);
 	used_ingredients_recipe = 0;
 	used_explicit_recipe = 0;
 	used_implicit_recipe = 0;
@@ -1171,6 +1171,7 @@ result = %8.8lX, imp=%d)\n{\n"/*}*/,
 	 */
 	if (desist_requested())
 	{
+		str_free(target);
 		result->status = graph_build_status_error;
 		result->gfp = 0;
 		trace((/*{*/"}\n"));
@@ -2151,6 +2152,7 @@ ret:
 	/*
 	 * report results for debug
 	 */
+	str_free(target);
 	assert((result->status == graph_build_status_success) ==
 		(result->gfp != 0));
 	trace
@@ -2159,7 +2161,7 @@ ret:
 		graph_build_status_name(result->status),
 		(long)result->gfp
 	));
-	trace((/*{*/"}\n"));
+	trace(("}\n"));
 }
 
 
