@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	cook - file construction tool
-#	Copyright (C) 1993-1997, 1999, 2001 Peter Miller;
+#	Copyright (C) 1993-1997, 1999, 2001, 2002 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -59,8 +59,11 @@ case $file in
 	echo "${stem}.gen.c ${stem}.gen.h: $file"
 	echo "	@echo Expect $numconf conflicts:"
 	echo "	\$(YACC) -d $file"
-	echo "	sed -e 's/[yY][yY]/${yy}_/g' -e '/#include.<stdio.h>/d' \
-			y.tab.c > ${stem}.gen.c"
+	echo "	sed -e 's/[yY][yY]/${yy}_/g'" \
+			"-e '/<stdio.h>/d'" \
+			"-e '/<stdlib.h>/d'" \
+			"-e '/<stddef.h>/d'" \
+			"y.tab.c > ${stem}.gen.c"
 	echo "	sed -e 's/[yY][yY]/${yy}_/g' -e 's/Y_TAB_H/${yy}_TAB_H/g' \
 			y.tab.h > ${stem}.gen.h"
 	echo "	rm y.tab.c y.tab.h"
@@ -101,8 +104,10 @@ lib/*/LC_MESSAGES/*.po)
 	stem=`echo $file | sed -e 's|^lib/\(.*\)\.po$|\1|'`
 	dir=`dirname $file`
 	echo ""
-	echo "lib/$stem.mo: $file $dir/common.po"
-	echo "	\$(MSGFMT) -o lib/$stem.mo $file $dir/common.po"
+	echo "lib/$stem.mo: $file $dir/common.po etc/msgfmt.sh"
+	echo "	sh etc/msgfmt.sh --msgfmt=\$(MSGFMT)" \
+		"--msgcat=\$(MSGCAT) --output=lib/$stem.mo" \
+		"$file $dir/common.po"
 	echo ""
 	echo "\$(libdir)/$stem.mo: lib/$stem.mo $dir/.libdir"
 	echo "	\$(INSTALL_DATA) lib/$stem.mo \$@"
